|
Neko 1.99.7
A portable framework for high-order spectral element flow simulations
|
#include "elem_block.h"

Go to the source code of this file.
Functions | |
| template<typename T , const int LX, const int CHUNKS> | |
| __global__ void | opgrad_kernel_1d (T *__restrict__ ux, T *__restrict__ uy, T *__restrict__ uz, const T *__restrict__ u, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ drdx, const T *__restrict__ dsdx, const T *__restrict__ dtdx, const T *__restrict__ drdy, const T *__restrict__ dsdy, const T *__restrict__ dtdy, const T *__restrict__ drdz, const T *__restrict__ dsdz, const T *__restrict__ dtdz, const T *__restrict__ w3) |
| template<typename T , const int LX, const int EB> | |
| __global__ void | __launch_bounds__ ((LX *LX *EB), 3) opgrad_kernel_kstep(T *__restrict__ ux |
| if (eb==0) | |
| for (int k=0;k< LX;++k) | |
| __syncthreads () | |
| __global__ void __launch_bounds__ | ( | (LX *LX *EB) | , |
| 3 | |||
| ) |
| __syncthreads | ( | ) |
| for | ( | ) |
| if | ( | eb | = = 0 | ) |
Definition at line 172 of file opgrad_kernel.h.
| __global__ void opgrad_kernel_1d | ( | T *__restrict__ | ux, |
| T *__restrict__ | uy, | ||
| T *__restrict__ | uz, | ||
| const T *__restrict__ | u, | ||
| const T *__restrict__ | dx, | ||
| const T *__restrict__ | dy, | ||
| const T *__restrict__ | dz, | ||
| const T *__restrict__ | drdx, | ||
| const T *__restrict__ | dsdx, | ||
| const T *__restrict__ | dtdx, | ||
| const T *__restrict__ | drdy, | ||
| const T *__restrict__ | dsdy, | ||
| const T *__restrict__ | dtdy, | ||
| const T *__restrict__ | drdz, | ||
| const T *__restrict__ | dsdz, | ||
| const T *__restrict__ | dtdz, | ||
| const T *__restrict__ | w3 | ||
| ) |
Device kernel for convective terms
Definition at line 45 of file opgrad_kernel.h.

Definition at line 164 of file opgrad_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ drdx |
Definition at line 135 of file opgrad_kernel.h.
Definition at line 138 of file opgrad_kernel.h.
Definition at line 141 of file opgrad_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dsdx |
Definition at line 136 of file opgrad_kernel.h.
Definition at line 139 of file opgrad_kernel.h.
Definition at line 142 of file opgrad_kernel.h.
Definition at line 137 of file opgrad_kernel.h.
Definition at line 140 of file opgrad_kernel.h.
Definition at line 143 of file opgrad_kernel.h.
Definition at line 132 of file opgrad_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dy |
Definition at line 133 of file opgrad_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dz |
Definition at line 134 of file opgrad_kernel.h.
| const int e_blk = blockIdx.x * EB + eb |
Definition at line 163 of file opgrad_kernel.h.
Definition at line 162 of file opgrad_kernel.h.
| const int i = threadIdx.x |
Definition at line 167 of file opgrad_kernel.h.
Definition at line 166 of file opgrad_kernel.h.
Definition at line 145 of file opgrad_kernel.h.
Definition at line 178 of file opgrad_kernel.h.
| __shared__ T shdx[LX *LX] |
Definition at line 151 of file opgrad_kernel.h.
| __shared__ T shdy[LX *LX] |
Definition at line 152 of file opgrad_kernel.h.
| __shared__ T shdz[LX *LX] |
Definition at line 153 of file opgrad_kernel.h.
Definition at line 131 of file opgrad_kernel.h.
| __global__ void T* __restrict__ uy |
Definition at line 129 of file opgrad_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ uz |
Definition at line 130 of file opgrad_kernel.h.
Definition at line 144 of file opgrad_kernel.h.